Installing — huey 2.0.0 documentation

# Installing

huey can be installed from PyPI using pip.

    $ pip install huey

huey has no dependencies outside the standard library, but redis-py is required to utilize Redis for your task storage:

    $ pip install redis

If your tasks are IO-bound rather than CPU-bound, you might consider using the `greenlet` worker type. To use the greenlet workers, you need to install `gevent`:

    pip install gevent

## Using git

If you want to run the very latest, you can clone the source repo and install the library:

    $ git clone https://github.com/coleifer/huey.git
    $ cd huey
    $ python setup.py install

You can run the tests using the test-runner:

    $ python setup.py test

The source code is available online at https://github.com/coleifer/huey